from server.Server import *
from protocol.Sms import *
from protocol.send.SendResponse import *
from base.Logger import *
import sys,time

class GatewayListener:

    """
        $Id: GatewayListener.py,v 1.1.1.1 2003/04/10 14:38:57 maro Exp $

        Connects to the gateway using the Server class, which calls callback-
        methods 'onSMSReceive' and 'onNotificationReceive' depending on type when
        messages arrives.

        @author maro
    """

    m_server = None
    m_log = None

    def __init__(self):
        """Constructor"""
        self.m_log = Logger()
        self.m_log.logInfo("Python-SDK %s" % self.m_log.m_conf.VERSION)

    def run(self):
        """Connects to gateway using the Server class and waits for messages"""
        self.m_server = Server(self.m_log.m_conf.LISTENER_HOST, self.m_log.m_conf.LISTENER_PORT)
        # Add this class as the request-listener, which means that the Server
        # will call methods in this class upon arrival
        self.m_server.addRequestListener(self)
        try:
            self.m_log.logInfo("Starting up ................: %s" % time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
            self.m_server.run()
        except KeyboardInterrupt:
            self.m_log.logInfo("Executing shutdown hook ....: %s" % time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
            self.m_server.shutdown()
            self.m_log.logInfo("Listener stopped")
            sys.exit()

    def onSMSReceive(self, sms):
        """Called by the Server when an SMS has been receive from the
            gateway."""
        self.m_log.logInfo("Got an SMS!")
        self.m_log.logInfo("  Message........: %s" % sms.getText())
        self.m_log.logInfo("  From ..........: %s" % sms.getOriginator())
        self.m_log.logInfo("  To ............: %s" % sms.getRecipient())
        self.m_log.logInfo("  Received ......: %s" % sms.getDelivered())
        #
        # Do some processing of the SMS here, then send response back to gateway
        #
        response = SendResponse()
        response.setStatus(response.STATUS_SUCCESS)
        self.m_server.sendResponse(response)

    def onNotificationReceive(self, notification):
        """Called by the Server when a Notification has been received from the
            gateway."""
        self.m_log.logInfo("Got a Notification!")
        self.m_log.logInfo("    Type ..........: %s" % notification.getNotificationTypeText())
        self.m_log.logInfo("    Message-id ....: %s" % notification.getMessageId())
        self.m_log.logInfo("    Received ......: %s" % notification.getProviderDate())
        #
        # Do some processing of the Notification here, then send response
        # to gateway
        #
        response = SendResponse()
        response.setStatus(response.STATUS_SUCCESS)
        self.m_server.sendResponse(response)


